<?php
namespace Folha\Entities;

use HCM\Util\DateUtil;
use Importacao\Logic\Integracao\ProjetoImportacao;

class MigContcorrparc extends Base\MigContcorrparc
{

    const DEFAULT_TP_CONTCORR = '3';

    /**
     * @param $nrcontcorrparc
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setNrcontcorrparc ($nrcontcorrparc) {
        $nrcontcorrparc = preg_replace("/[^0-9]/","", $nrcontcorrparc); // somente numeros
        $nrcontcorrparc = \Importacao\Logic\Validacoes::verificaChaveDuplicada('CONTCORRPARC', 'NRCONTCORRPARC', ProjetoImportacao::getNrorg(), $nrcontcorrparc);
        $this->nrcontcorrparc = $nrcontcorrparc;
    }

    /**
     * @param $nrparcnegocio
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setNrparcnegocio ($nrparcnegocio) {
        $nrorg = ProjetoImportacao::getNrorg();
        $parcnegocio = \Folha\Entities\MigParcnegocio::getObjectByWhere('NRPARCNEGOCIO = ? AND NRORG = ?', array($nrparcnegocio, $nrorg));

        if (is_object($parcnegocio)) {
            $this->nrparcnegocio = $nrparcnegocio;
        } else {
            throw new \Exception("O código do Parceiro de Negócio '$nrparcnegocio' não foi encontrado.");
        }
    }

    /**
     * @param $nrtpcontcorr
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setNrtpcontcorr ($nrtpcontcorr) {
        try {
            $nrorg = ProjetoImportacao::getNrorgPadrao();
            $tipocontcorr = \Teknisa\Entities\Tpcontcorr::getEntityByWhere('NRTPCONTCORR = ? AND NRORG = ?', array($nrtpcontcorr, $nrorg));

            if (is_object($tipocontcorr)) {
                $this->nrtpcontcorr = $nrtpcontcorr;
            } else {
                $this->nrtpcontcorr = self::DEFAULT_TP_CONTCORR;
            }
        } catch(\Exception $e) {
            throw new \Exception("O código de Conta Corrente '$nrtpcontcorr' não foi encontrado.");
        }
    }

    /**
     * @param $cdbanco
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setCdbanco ($cdbanco) {
        if (empty($cdbanco)) {
            throw new \Exception("Campo Obrigatório: 'Banco'");
        }
        $cdbanco = preg_replace("/[^0-9]/","", $cdbanco); // somente numeros
        $this->cdbanco = $cdbanco;
    }

    /**
     * @param $cdagencia
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setCdagencia ($cdagencia) {
        if (empty($cdagencia)) {
            throw new \Exception("Campo Obrigatório: 'Agência'");
        }
        $cdagencia = preg_replace("/[^0-9]/","", $cdagencia); // somente numeros
        $this->cdagencia = $cdagencia;
    }

    /**
     * @param $cdcontcorr
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc
     */
    public function setCdcontcorr ($cdcontcorr) {
        if (empty($cdcontcorr)) {
            throw new \Exception("Campo Obrigatório: 'Conta Corrente'");
        }
        $cdcontcorr = preg_replace("/[^0-9]/","", $cdcontcorr); // somente numeros
        $this->cdcontcorr = $cdcontcorr;
    }

    /**
     * @param mixed $dtinclusao
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc|void
     */
    public function setDtinclusao($dtinclusao)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtinclusao)) {
            throw new \Exception("Data '$dtinclusao' com formato inválido ou em branco.");
        }

        if (!($dtinclusao instanceof \DateTime)) {
            $dtinclusao = DateUtil::getDataDeString($dtinclusao);
        }

        $this->dtinclusao = $dtinclusao;
    }

    /**
     * @param mixed $dtultatu
     * @throws \Exception
     * @return \Folha\Entities\MigContcorrparc|void
     */
    public function setDtultatu($dtultatu)
    {
        if (!preg_match("/\d{2}\/\d{2}\/\d{4}/", $dtultatu)) {
            throw new \Exception("Data '$dtultatu' com formato inválido ou em branco.");
        }

        if (!($dtultatu instanceof \DateTime)) {
            $dtultatu = DateUtil::getDataDeString($dtultatu);
        }

        $this->dtultatu = $dtultatu;
    }

}